/*
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file "COPYING" in the main directory of this archive
 * for more details.
 *
 * Copyright (C) 2013 Qtechnology/AS
 * ricardo.ribalda@gmail.com
 *
 */
#ifndef QTEC_VIDEO_H
#define QTEC_VIDEO_H

#include <linux/types.h>
#include <linux/v4l2-controls.h>

struct qtec_distortion {
	__u16 col_res;
	__s16 col;
	__u16 line_res;
	__s16 line;
};

#define QTEC_VIDEO_CID_BASE (V4L2_CID_USER_BASE + 0x100)
enum {
	QTEC_VIDEO_CID_DROP_FRAMES = QTEC_VIDEO_CID_BASE,
	QTEC_VIDEO_CID_ACTIVE_FRAMES,
	QTEC_VIDEO_CID_BUFFER_SIZE,
	QTEC_VIDEO_CID_SENSOR_TYPE,
	QTEC_VIDEO_CID_SENSOR_SERIAL,
	QTEC_VIDEO_CID_BITSTREAM_VERSION,
	QTEC_VIDEO_CID_RESET_PIPELINE,
	QTEC_VIDEO_CID_DEAD_PIXELS,
	QTEC_VIDEO_CID_HEAD_I2C_ADDR,
	QTEC_VIDEO_CID_HEAD_I2C_BUS,
	QTEC_VIDEO_CID_FRAME_COUNTER,
};

#define QTEC_WHITE_CID_BASE (V4L2_CID_USER_BASE + 0x200)
enum {
	QTEC_WHITE_CID_GREEN_BALANCE = QTEC_WHITE_CID_BASE,
	QTEC_WHITE_CID_IR1_BALANCE,
	QTEC_WHITE_CID_IR2_BALANCE,
	QTEC_WHITE_CID_COMPACT_BALANCE,
	QTEC_WHITE_CID_RED_OFFSET,
	QTEC_WHITE_CID_GREEN_OFFSET,
	QTEC_WHITE_CID_BLUE_OFFSET,
	QTEC_WHITE_CID_IR1_OFFSET,
	QTEC_WHITE_CID_IR2_OFFSET,
	QTEC_WHITE_CID_COMPACT_OFFSET,
};

#define QTEC_CMOSIS_CID_BASE (V4L2_CID_USER_BASE + 0x300)
enum {
	QTEC_CMOSIS_CID_MODE_TRIG = QTEC_CMOSIS_CID_BASE,
	QTEC_CMOSIS_CID_PHASE,
	QTEC_CMOSIS_CID_FLASH_POL,
	QTEC_CMOSIS_CID_TRIG_POL,
	QTEC_CMOSIS_CID_ADC_GAIN,
	QTEC_CMOSIS_CID_OFFSET,
	QTEC_CMOSIS_CID_MANUAL_TRIGGER,
	QTEC_CMOSIS_CID_EXT_TRIG_DELAY,
	QTEC_CMOSIS_CID_EXT_TRIG_OVERFLOW,
	QTEC_CMOSIS_CID_TEMPERATURE,
	QTEC_CMOSIS_CID_VRAMP,
	QTEC_CMOSIS_CID_H_BINNING,
	QTEC_CMOSIS_CID_V_BINNING,
	QTEC_CMOSIS_CID_OUTPUT_SCALER,
	QTEC_CMOSIS_CID_BAYER_SKIPPING,
	QTEC_CMOSIS_CID_FPN,
	QTEC_CMOSIS_CID_N_CHANNELS,
	QTEC_CMOSIS_CID_BITMODE,
	QTEC_CMOSIS_CID_RESPONSE_CURVE,
	QTEC_CMOSIS_CID_TRACE_TRIGGER,
	QTEC_CMOSIS_CID_TRACE_FRAME,
	QTEC_CMOSIS_CID_TRACE_READOUT,
	QTEC_CMOSIS_CID_FLASH_DISABLE,
	QTEC_CMOSIS_CID_EXPOSURE_STEP,
	QTEC_CMOSIS_CID_DUAL_EXPOSURE,
	QTEC_CMOSIS_CID_BAYER_INTERPOLATOR_MODE,
	QTEC_CMOSIS_CID_FLASH_WARM_UP,
	QTEC_CMOSIS_CID_FLASH_TIME,
	QTEC_CMOSIS_CID_FLASH_DURING_EXPOSURE,
	QTEC_CMOSIS_CID_TEMP_CALIB_OFFSET,
	QTEC_CMOSIS_CID_TEMP_CALIB_SLOPEK,
	QTEC_CMOSIS_CID_TRIGGER_SEQUENCE,
	QTEC_CMOSIS_CID_ROT,
	QTEC_CMOSIS_CID_FOT,
	QTEC_CMOSIS_CID_TFRAME,
	QTEC_CMOSIS_CID_BUS_CLK,
	QTEC_CMOSIS_CID_FB_CLK,
	QTEC_CMOSIS_CID_LVDS_CLK,
	QTEC_CMOSIS_CID_PIXEL_CLK,
	QTEC_CMOSIS_CID_LINE_LEN,
};

#define QTEC_XFORM_CID_BASE (V4L2_CID_USER_BASE + 0x400)
enum {
	QTEC_XFORM_CID_ENABLE_DIST_MAP = QTEC_XFORM_CID_BASE,
	QTEC_XFORM_CID_ENABLE_GAIN_MAP,
	QTEC_XFORM_CID_EXTRA_GAIN,
	QTEC_XFORM_CID_DIST_BUFFER_SIZE,
	QTEC_XFORM_CID_FIFO_SIZE,
	QTEC_XFORM_CID_MIN_FIFO_LEVEL,
	QTEC_XFORM_CID_HFLIP,
	QTEC_XFORM_CID_GAIN,
	QTEC_XFORM_CID_GAIN_MAP,
};

#define QTEC_CCD_CID_BASE (V4L2_CID_USER_BASE + 0x500)
enum {
	QTEC_CCD_CID_RED_EXPOSURE = QTEC_CCD_CID_BASE,
	QTEC_CCD_CID_GREEN_EXPOSURE,
	QTEC_CCD_CID_BLUE_EXPOSURE,
	QTEC_CCD_CID_IR1_EXPOSURE,
	QTEC_CCD_CID_IR2_EXPOSURE,
	QTEC_CCD_CID_CDS,
	QTEC_CCD_CID_RED_CDS,
	QTEC_CCD_CID_GREEN_CDS,
	QTEC_CCD_CID_BLUE_CDS,
	QTEC_CCD_CID_IR1_CDS,
	QTEC_CCD_CID_IR2_CDS,
	QTEC_CCD_CID_RED_VGAGAIN,
	QTEC_CCD_CID_GREEN_VGAGAIN,
	QTEC_CCD_CID_BLUE_VGAGAIN,
	QTEC_CCD_CID_IR1_VGAGAIN,
	QTEC_CCD_CID_IR2_VGAGAIN,
	QTEC_CCD_CID_EXT_TRIG_DELAY,
	QTEC_CCD_CID_MODE_TRIG,
	QTEC_CCD_CID_FLASH_POL,
	QTEC_CCD_CID_TRIG_POL,
	QTEC_CCD_CID_MANUAL_TRIGGER,
};

#define QTEC_TESTGEN_CID_BASE (V4L2_CID_USER_BASE + 0x600)
enum {
	QTEC_TESTGEN_MISSED_FRAMES = QTEC_TESTGEN_CID_BASE,
};

#define QTEC_ROIC_CID_BASE (V4L2_CID_USER_BASE + 0x700)
enum {
	QTEC_ROIC_CID_MODE_TRIG = QTEC_ROIC_CID_BASE,
	QTEC_ROIC_CID_FLASH_POL,
	QTEC_ROIC_CID_TRIG_POL,
	QTEC_ROIC_CID_MANUAL_TRIGGER,
	QTEC_ROIC_CID_EXT_TRIG_DELAY,
	QTEC_ROIC_CID_EXT_TRIG_OVERFLOW,
	QTEC_ROIC_CID_VOLT_GOC,
	QTEC_ROIC_CID_VOLT_VSK,
	QTEC_ROIC_CID_VOLT_GFID,
	QTEC_ROIC_CID_VOLT_VDETCOM,
	QTEC_ROIC_CID_VOLT_AD_OFFSET,
	QTEC_ROIC_CID_VOLT_AD_GAIN,
	QTEC_ROIC_CID_TEMPERATURE,
	QTEC_ROIC_CID_ITR,
	QTEC_ROIC_CID_IMRO,
	QTEC_ROIC_CID_NDRO,
	QTEC_ROIC_CID_RE,
	QTEC_ROIC_CID_RST,
	QTEC_ROIC_CID_OE_EN,
	QTEC_ROIC_CID_PW,
	QTEC_ROIC_CID_I,
	QTEC_ROIC_CID_AP,
	QTEC_ROIC_CID_BW,
	QTEC_ROIC_CID_TS,
	QTEC_ROIC_CID_AUTO_OFF,
	QTEC_ROIC_CID_PIXEL_CLK,
	QTEC_ROIC_CID_VTEMP_PIN,
	QTEC_ROIC_CID_VTEMP_1,
	QTEC_ROIC_CID_VTEMP_2,
	QTEC_ROIC_CID_VOLT_GSK,
	QTEC_ROIC_CID_VOLT_VBUS,
};

// ROIC and LWIR can share the same base
#define QTEC_LWIR_CID_BASE (V4L2_CID_USER_BASE + 0x700)
enum {
	QTEC_LWIR_CID_MODE_TRIG = QTEC_ROIC_CID_BASE,
	QTEC_LWIR_CID_FLASH_POL,
	QTEC_LWIR_CID_TRIG_POL,
	QTEC_LWIR_CID_MANUAL_TRIGGER,
	QTEC_LWIR_CID_EXT_TRIG_DELAY,
	QTEC_LWIR_CID_EXT_TRIG_OVERFLOW,
	QTEC_LWIR_CID_VOLT_AD_OFFSET,
	QTEC_LWIR_CID_VOLT_AD_GAIN,
	QTEC_LWIR_CID_TEMPERATURE,
	QTEC_LWIR_CID_VTEMP_1,
	QTEC_LWIR_CID_VOLT_GSK,
	QTEC_LWIR_CID_VOLT_VBUS,
	QTEC_LWIR_CID_VOLT_GOC,
	QTEC_LWIR_CID_VOLT_VSK,
	QTEC_LWIR_CID_VOLT_GFID,
	QTEC_LWIR_CID_OUTPUT_SCALER,
	QTEC_LWIR_CID_PATTERN_GENERATOR,
};

#define QTEC_M43_CID_BASE (V4L2_CID_USER_BASE + 0x800)
enum {
	QTEC_M43_CID_LENS_ACTIVE = QTEC_M43_CID_BASE,
	QTEC_M43_CID_LENS_NAME,
	QTEC_M43_CID_LENS_VERSION,
	QTEC_M43_CID_APERTURE,
	QTEC_M43_CID_FOCAL_LENGTH,
	QTEC_M43_CID_FOCAL_LENGTH_NON_BLOCKING,
	QTEC_M43_CID_FOCUS,
	QTEC_M43_CID_LENS_MOVING,
};

#define QTEC_PAN_CID_BASE (V4L2_CID_USER_BASE + 0x900)
enum {
	QTEC_PAN_CID_AXIS0_POSITION = QTEC_PAN_CID_BASE,
	QTEC_PAN_CID_AXIS1_POSITION,
	QTEC_PAN_CID_AXIS0_SPEED,
	QTEC_PAN_CID_AXIS1_SPEED,
	QTEC_PAN_CID_AXIS0_CALIBRATION,
	QTEC_PAN_CID_AXIS1_CALIBRATION,
	QTEC_PAN_CID_AXIS0_CURRENT_POSITION,
	QTEC_PAN_CID_AXIS1_CURRENT_POSITION,
	QTEC_PAN_CID_AXIS0_VMIN,
	QTEC_PAN_CID_AXIS1_VMIN,
	QTEC_PAN_CID_AXIS0_AMAX,
	QTEC_PAN_CID_AXIS1_AMAX,
	QTEC_PAN_CID_AXIS0_PMUL,
	QTEC_PAN_CID_AXIS1_PMUL,
	QTEC_PAN_CID_AXIS0_PDIV,
	QTEC_PAN_CID_AXIS1_PDIV,
	QTEC_PAN_CID_AXIS0_IRUN,
	QTEC_PAN_CID_AXIS1_IRUN,
	QTEC_PAN_CID_AXIS0_IHOLD,
	QTEC_PAN_CID_AXIS1_IHOLD,
	QTEC_PAN_CID_AXIS0_PULSERAMP,
	QTEC_PAN_CID_AXIS1_PULSERAMP,
	QTEC_PAN_CID_AXIS0_SOFTMODE,
	QTEC_PAN_CID_AXIS1_SOFTMODE,
};

#define QTEC_ENCODER_CID_BASE (V4L2_CID_USER_BASE + 0xa00)
enum {
	QTEC_ENCODER_CID_ENCODER_POSITION = QTEC_ENCODER_CID_BASE,
};

#define QTEC_LUT_CID_BASE (V4L2_CID_USER_BASE + 0xb00)
enum {
	QTEC_LUT_CID_LUT_MONO = QTEC_LUT_CID_BASE,
	QTEC_LUT_CID_LUT_RED,
	QTEC_LUT_CID_LUT_GREEN,
	QTEC_LUT_CID_LUT_BLUE,
};

#define QTEC_CONV_CID_BASE (V4L2_CID_USER_BASE + 0xc00)
enum {
	QTEC_CONV_CID_KERNEL_MONO = QTEC_CONV_CID_BASE,
	QTEC_CONV_CID_KERNEL_RED,
	QTEC_CONV_CID_KERNEL_GREEN,
	QTEC_CONV_CID_KERNEL_BLUE,
	QTEC_CONV_CID_KERNEL_MONO_1,
	QTEC_CONV_CID_KERNEL_RED_1,
	QTEC_CONV_CID_KERNEL_GREEN_1,
	QTEC_CONV_CID_KERNEL_BLUE_1,
};

#define QTEC_BOTTLE_CID_BASE (V4L2_CID_USER_BASE + 0xd00)
enum {
	QTEC_BOTTLE_CID_MOVE = QTEC_BOTTLE_CID_BASE,
	QTEC_BOTTLE_CID_SPEED,
};

#define QTEC_SONY_CID_BASE (V4L2_CID_USER_BASE + 0xe00)
enum {
	QTEC_SONY_CID_BITMODE = QTEC_SONY_CID_BASE,
	QTEC_SONY_CID_N_CHANNELS,
	QTEC_SONY_CID_FLASH_POL,
	QTEC_SONY_CID_FLASH_DISABLE,
	QTEC_SONY_CID_FPN,
	QTEC_SONY_CID_H_BINNING,
	QTEC_SONY_CID_V_BINNING,
	QTEC_SONY_CID_OUTPUT_SCALER,
	QTEC_SONY_CID_MODE_TRIG,
	QTEC_SONY_CID_MANUAL_TRIGGER,
	QTEC_SONY_CID_EXT_TRIG_OVERFLOW,
	QTEC_SONY_CID_TRIG_POL,
	QTEC_SONY_CID_PATTERN_GENERATOR,
	QTEC_SONY_CID_EXT_TRIG_DELAY,
	QTEC_SONY_CID_FLASH_DURING_EXPOSURE,
	QTEC_SONY_CID_FLASH_WARM_UP,
	QTEC_SONY_CID_FLASH_TIME,
	QTEC_SONY_CID_BAYER_INTERPOLATOR_MODE,
	QTEC_SONY_CID_AEG_ENABLE,
	QTEC_SONY_CID_AEG_REFVAL,
	QTEC_SONY_CID_AEG_MIN_EXP,
	QTEC_SONY_CID_UNIT_CELL_SIZE_PROCESSED,
	QTEC_SONY_CID_TEMPERATURE,
	QTEC_SONY_CID_TC,
	QTEC_SONY_CID_TC_KD,
	QTEC_SONY_CID_TC_KI,
	QTEC_SONY_CID_TC_KP,
	QTEC_SONY_CID_TC_TREF,
	QTEC_SONY_CID_CONVERSION_GAIN_HIGH,
	QTEC_SONY_CID_VERTICAL_SUBSAMPLING,
};

#define QTEC_LEDCTRL_CID_BASE (V4L2_CID_USER_BASE + 0xf00)
enum {
	QTEC_LEDCTRL_OUTPUT_CURRENT1 = QTEC_LEDCTRL_CID_BASE,
	QTEC_LEDCTRL_OUTPUT_CURRENT2,
	QTEC_LEDCTRL_OUTPUT_CURRENT3,
	QTEC_LEDCTRL_OUTPUT_CURRENT4,
	QTEC_LEDCTRL_OUTPUT_CURRENT5,
	QTEC_LEDCTRL_OUTPUT_CURRENT6,
	QTEC_LEDCTRL_OUTPUT_CURRENT7,
	QTEC_LEDCTRL_OUTPUT_CURRENT8,
	QTEC_LEDCTRL_MAX_ON_TIME1,
	QTEC_LEDCTRL_MAX_ON_TIME2,
	QTEC_LEDCTRL_MAX_ON_TIME3,
	QTEC_LEDCTRL_MAX_ON_TIME4,
	QTEC_LEDCTRL_MAX_ON_TIME5,
	QTEC_LEDCTRL_MAX_ON_TIME6,
	QTEC_LEDCTRL_MAX_ON_TIME7,
	QTEC_LEDCTRL_MAX_ON_TIME8,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE1,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE2,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE3,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE4,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE5,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE6,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE7,
	QTEC_LEDCTRL_MAX_DUTY_CYCLE8,
	QTEC_LEDCTRL_MIN_ON_TIME1,
	QTEC_LEDCTRL_MIN_ON_TIME2,
	QTEC_LEDCTRL_MIN_ON_TIME3,
	QTEC_LEDCTRL_MIN_ON_TIME4,
	QTEC_LEDCTRL_MIN_ON_TIME5,
	QTEC_LEDCTRL_MIN_ON_TIME6,
	QTEC_LEDCTRL_MIN_ON_TIME7,
	QTEC_LEDCTRL_MIN_ON_TIME8,
	QTEC_LEDCTRL_MIN_FREQ1,
	QTEC_LEDCTRL_MIN_FREQ2,
	QTEC_LEDCTRL_MIN_FREQ3,
	QTEC_LEDCTRL_MIN_FREQ4,
	QTEC_LEDCTRL_MIN_FREQ5,
	QTEC_LEDCTRL_MIN_FREQ6,
	QTEC_LEDCTRL_MIN_FREQ7,
	QTEC_LEDCTRL_MIN_FREQ8,
};

#define QTEC_GSENSE_CID_BASE (V4L2_CID_USER_BASE + 0x1000)
enum {
	QTEC_GSENSE_CID_ROLLING_LG_IMAGE = QTEC_GSENSE_CID_BASE,
	QTEC_GSENSE_CID_ADC_GAIN_RS,
	QTEC_GSENSE_CID_ADC_GAIN_GS,
	QTEC_GSENSE_CID_PGA_GAIN_LG,
	QTEC_GSENSE_CID_GLOBAL_SHUTTER,
	QTEC_GSENSE_CID_MODE_TRIG,
	QTEC_GSENSE_CID_TRIG_POL,
	QTEC_GSENSE_CID_EXT_TRIG_DELAY,
	QTEC_GSENSE_CID_EXT_TRIG_OVERFLOW,
	QTEC_GSENSE_CID_FLASH_POL,
	QTEC_GSENSE_CID_FLASH_DISABLE,
	QTEC_GSENSE_CID_FLASH_TIME,
	QTEC_GSENSE_CID_FLASH_DURING_EXPOSURE,
	QTEC_GSENSE_CID_MANUAL_TRIGGER,
	QTEC_GSENSE_CID_VOLT_VTD,
	QTEC_GSENSE_CID_FPN,
	QTEC_GSENSE_CID_LINE_EXPOSURE_SEQUENCE,
	QTEC_GSENSE_CID_OFFSET_LG,
	QTEC_GSENSE_CID_OFFSET_HG,
	QTEC_GSENSE_CID_TEMPERATURE,
	QTEC_GSENSE_CID_H_BINNING,
	QTEC_GSENSE_CID_V_BINNING,
	QTEC_GSENSE_CID_LINE_ORDER,
	QTEC_GSENSE_CID_FULL_SPEED,
	QTEC_GSENSE_CID_START_UP_DELAY,
};

#define QTEC_XRAY_CID_BASE (V4L2_CID_USER_BASE + 0x1100)
enum {
	QTEC_XRAY_CID_VOLT_AD_OFFSET = QTEC_XRAY_CID_BASE,
	QTEC_XRAY_CID_VOLT_AD_GAIN,
	QTEC_XRAY_CID_OUTPUT_SCALER,
	QTEC_XRAY_CID_CHANNEL_OFFSET,
	QTEC_XRAY_CID_INVERT_VALUES,
	QTEC_XRAY_CID_FLASH_INTERVAL_LINES,
};

#define QTEC_COLOR_CONV_CID_BASE (V4L2_CID_USER_BASE + 0x1200)
enum {
	QTEC_COLOR_CONV_CID_ENABLED = QTEC_COLOR_CONV_CID_BASE,
	QTEC_COLOR_CONV_CID_SATURATION,
	QTEC_COLOR_CONV_CID_OFFSET,
	QTEC_COLOR_CONV_CID_MATRIX,
};

#endif
